<?php

/**
 * Elementor Single Widget
 * @package purefit-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Purefit_Products_V2 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-products-v2';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Products V2', 'purefit-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'purefit-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['purefit_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Content', 'purefit-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new Repeater();

        $repeater->add_control(
            'select_product',
            [
                'label' => esc_html__('Select a product', 'purefit-core'),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' => $this->get_all_products(),
                'default' => 'none'
            ]
        );

        $repeater->add_control(
            'product_image',
            [
                'type' => Controls_Manager::MEDIA,
                'label' => __('Product Image', 'purefit-core'),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'products_lists',
            [
                'show_label' => false,
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'purefit-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'bg-c',
            [
                'label' => esc_html__('Background Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .popular-product-item' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'padding',
            [
                'label' => esc_html__('Padding', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .popular-product-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .popular-product-item .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'title_hover-c',
            [
                'label' => esc_html__('Title Hover Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .popular-product-item .xb-item--title:hover a' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .popular-product-item .xb-item--title',
            ]
        );
        $this->add_control(
            'price_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'price-c',
            [
                'label' => esc_html__('Price Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .popular-product-item .xb-item--price' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'price_typography',
                'selector' => '{{WRAPPER}} .popular-product-item .xb-item--price',
            ]
        );
        $this->add_control(
            'cart_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'cart_icon_bg-c',
            [
                'label' => esc_html__('Cart Icon BG Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .popular-product-item .xb-item--cart' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_section();

    }

    // Get Product Lists
    public function get_all_products()
    {
        $products = wc_get_products([
            'status' => 'publish',
            'orderby' => 'name',
            'order' => 'DESC',
            'limit' => -1,
        ]);

        $options = ['none' => 'None'];
        foreach ($products as $product) {
            $options[$product->get_id()] = $product->get_name();
        }

        return $options;
    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $bag = PUREFIT_DIR_URL . 'assets/img/bag.svg';
        ?>
        <div class="row">
            <?php foreach ($settings['products_lists'] as $item) :
                $product_details = wc_get_product($item['select_product']);

                if (empty($product_details)) {
                    return;
                }
                ?>

                <div class="col-lg-6 col-md-6 mt-20">
                    <div class="popular-product-item ul_li">
                        <div class="xb-item--img">
                            <a href="<?php echo get_permalink($product_details->get_id()) ?>"><img
                                        src="<?php echo esc_url($item['product_image']['url']); ?>"
                                        alt="<?php echo esc_attr__('img', 'purefit-core') ?>"></a>
                        </div>
                        <div class="xb-item--holder">
                            <h3 class="xb-item--title"><a
                                        href="<?php echo get_permalink($product_details->get_id()) ?>"><?php echo esc_html($product_details->get_name()); ?></a></h3>
                            <div class="xb-item--rating-inner ul_li">
                                <div class="xb-item--rating ul_li">
                                    <?php
                                    if ($average = $product_details->get_average_rating()) {
                                        echo '<div class="star-rating" title="' . sprintf(__('Rated %s out of 5', 'purefit-core'), $average) . '"><span style="width:' . (($average / 5) * 100) . '%"><strong itemprop="ratingValue" class="rating">' . $average . '</strong> ' . __('out of 5', 'purefit-core') . '</span></div>';
                                    } else {
                                        for ($i = 0; $i < 5; $i++) {
                                            echo '<span><i class="far fa-star"></i></span>';
                                        }
                                    }
                                    ?>
                                </div>
                                <span>(<?php echo $product_details->get_rating_count(); ?>)</span>
                            </div>
                            <div class="xb-item--action ul_li_between">
                                <h4 class="xb-item--price"><?php echo wp_kses($product_details->get_price_html(), true); ?></h4>
                                <a class="xb-item--cart" href="<?php echo get_permalink($product_details->get_id()) ?>"><img src="<?php echo esc_url($bag); ?>" alt=""></a>
                            </div>
                        </div>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Purefit_Products_V2());